#include <iostream>
#include <vector>
#include <set>
#include <algorithm>
#include <functional>

using namespace std;

int components(vector<vector<int>> g){
    vector<bool> visited(g.size(), false);

    function<void(int)> dfs = [&dfs, &g, &visited](int i)->void{
        visited[i]=true;
        for(int j = 0;j<g[i].size();j++){
            if(!visited[g[i][j]]){
                dfs(g[i][j]);
            }
        }
    };

    int components=0;
    for(int i = 0; i < g.size(); i++){
        if(!visited[i]){
            components++;
            dfs(i);
        }
    }
    return components;
}

vector<pair<int, int>> read(int n){
    vector<pair<int, int>> a(n, make_pair(0,0));
    for(int i=0;i<n;i++){
        int t;
        cin >> t;
        a[i].first=t;
    }
    for(int i=0;i<n;i++){
        int t;
        cin >> t;
        a[i].second=t;
    }
    return a;
}

pair<vector<int>, vector<int>> read2(int n){
    vector<int> a;
    for(int i=0;i<n;i++){
        int t;
        cin >> t;
        a.push_back(t);
    }
    vector<int> b;
    for(int i=0;i<n;i++){
        int t;
        cin >> t;
        b.push_back(t);
    }
    return make_pair(a,b);
}

vector<vector<int>> get_graph(pair<vector<int>, vector<int>> t){
    vector<vector<int>> g;
    for(int i = 0;i<t.first.size();i++){
        vector<int> a;
        for(int j = 0;j<i;j++){
            bool p = t.first[i]<t.first[j];
            bool q = t.second[i]<t.second[j];
            if(p ^ q){
                a.push_back(j);
                g[j].push_back(i);
            }
        }
        g.push_back(a);
    }
    return g;
}


template<class T, class U>
int lower_bound(vector<T> t, U k, function<int(T,U)> comp){
    int p = -1;
    int q = t.size();
    while(q-p>1){
        int s = (p+q)/2;
        if(comp(t[s], k) < 0){
            p = s;
        }
        else {
            q = s;
        }
    }
    return p;
}

template<class T, class U>
int upper_bound(vector<T> t, U k, function<int(T,U)> comp){
    int p = -1;
    int q = t.size();
    while(q-p>1){
        int s = (p+q)/2;
        if(comp(t[s], k) <= 0){
            p = s;
        }
        else {
            q = s;
        }
    }
    return q;
}

int main(){
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int n;
    cin >>n;
    if(n <=5000){
        cout << components(get_graph(read2(n)));
        return 0;
    }

    auto t = read(n);

    vector<pair<pair<int, int>,pair<int, int>>> components;
    for(int i = 0;i<t.size();i++){
        int j = lower_bound<pair<pair<int, int>,pair<int, int>>, int>(components, t[i].first, [](pair<pair<int, int>,pair<int, int>> a, int b)->int{
                                                                                            return a.first.second - b;
                                                                                         }) + 1;
        int k = lower_bound<pair<pair<int, int>,pair<int, int>>, int>(components, t[i].second, [](pair<pair<int, int>,pair<int, int>> a, int b)->int{
                                                                                            return a.second.second - b;
                                                                                         }) + 1;
        if(j < k){
            components[j] = make_pair(
                               make_pair(min(t[i].first, components[j].first.first), components[j].first.second),
                               make_pair(components[k - 1].second.first, t[i].second)
                               );
            components.erase(components.begin() + j + 1, components.begin()+k);
        }
        else if(j>k){
            components[k] = make_pair(
                               make_pair(components[j - 1].first.first, t[i].first),
                               make_pair(min(t[i].second, components[k].second.first), components[k].second.second)
                               );
            components.erase(components.begin() + k + 1, components.begin()+j);
        }
        else{
            if(j>=components.size() ||(t[i].first < components[j].first.first && t[i].second < components[j].second.first)){
                auto temp = make_pair(make_pair(0,0),make_pair(0,0));
                components.push_back(temp);
                for(int l = components.size() - 1;l> j;l--)
                    components[l]=components[l-1];
                components[j] = make_pair(make_pair(t[i].first,t[i].first),make_pair(t[i].second,t[i].second));
            }
            else {
                components[j] = make_pair(
                               make_pair(min(t[i].first, components[j].first.first), components[j].first.second),
                               make_pair(min(t[i].second, components[j].second.first), components[j].second.second)
                               );
            }
        }
    }
    cout << components.size();

    return 0;
}