#include <algorithm>
#include <iostream>
#include <vector>
#include <queue>
#include <map>
#include <set>
using namespace std;
typedef long long ll;

bool is_valid_cell(int row, int col, int n, int m)
{
	return !(row < 0 || col < 0 || row >= n || col >= m);
}

set<int> in_degree_zero;

void update(const vector<vector<int>>& mat, int row, int col, int n, int m, vector<int>& in_degree)
{
	vector<int> d_row = { -1,1,0,0 }, d_col = { 0,0,-1,1 };
	in_degree[row*n+col] = 0;
	for (int d = 0; d < 4; d++)
	{
		int neighbor_row = row + d_row[d];
		int neighbor_col = col + d_col[d];
		if (is_valid_cell(neighbor_row, neighbor_col, n, m))
		{
			if (mat[neighbor_row][neighbor_col] < mat[row][col])
				in_degree[row * n + col]++;
		}
	}
	if (in_degree[row*n+col] == 0 && mat[row][col] > 0)
	{
		in_degree_zero.insert(row * n + col);
	}
	else
	{
		if (in_degree_zero.find(row*n+col) != in_degree_zero.end())
		{
			in_degree_zero.erase(row * n + col);
		}
	}
}
void update_neighbors(const vector<vector<int>>& mat, int row, int col, int n, int m, vector<int>& in_degree)
{
	vector<int> d_row = { -1,1,0,0 }, d_col = { 0,0,-1,1 };
	for (int d = 0; d < 4; d++)
	{
		int neighbor_row = row + d_row[d];
		int neighbor_col = col + d_col[d];
		if (is_valid_cell(neighbor_row, neighbor_col, n, m))
		{
			if (mat[neighbor_row][neighbor_col] < mat[row][col])
				update(mat, neighbor_row, neighbor_col, n, m, in_degree);
		}
	}
}

int main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);
	int n, m, q;
	cin >> n >> m >> q;
	vector<vector<int>> mat(n, vector<int>(m));
	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++)
		{
			cin >> mat[i][j];
			mat[i][j]--;
		}
	}
	vector<int> in_degree(n*m);
	vector<int> d_row = { -1,1,0,0 }, d_col = {0,0,-1,1};

	for (int row = 0; row < n; row++)
	{
		for (int col = 0; col < m; col++)
		{
			for (int d = 0; d < 4; d++)
			{
				int neighbor_row = row + d_row[d];
				int neighbor_col = col + d_col[d];
				if (is_valid_cell(neighbor_row,neighbor_col,n,m))
				{
					if (mat[neighbor_row][neighbor_col] < mat[row][col])
						in_degree[row * n + col]++;
				}
			}
			if (in_degree[row * n + col] == 0 && mat[row][col] > 0)
			{
				in_degree_zero.insert(row * n + col);
			}
		}
	}

	if (in_degree_zero.empty())
		cout << "DA\n";
	else
		cout << "NE\n";

	for (int i = 0; i < q; i++)
	{
		int row1, col1, row2, col2;
		cin >> row1 >> col1 >> row2 >> col2;
		row1--; row2--; col1--; col2--;
		swap(mat[row1][col1], mat[row2][col2]);
		update(mat, row1, col1, n, m, in_degree);
		update_neighbors(mat, row1, col1, n, m, in_degree);
		update(mat, row2, col2, n, m, in_degree);
		update_neighbors(mat, row2, col2, n, m, in_degree);
		if (in_degree_zero.empty())
			cout << "DA\n";
		else
			cout << "NE\n";
	}
	return 0;
}