#include <algorithm>
#include <iostream>
#include <vector>
#include <queue>
#include <map>
#include <set>
using namespace std;
typedef long long ll;

ll mod = 1e9 + 7;
ll gcd(ll a, ll b)
{
	if (b == 0)
		return a;
	return gcd(b, a % b);
}

ll fact(ll n)
{
	ll f = 1;
	for (int i = 2; i <= n; i++)
	{
		f *= i;
		f %= mod;
	}
	return f;
}

ll brutus(vector<ll> e)
{
	ll multiply = 1;
	map<int, int> cnt_of_number;
	for (size_t i = 0; i < e.size(); i++)
		cnt_of_number[e[i]]++;
	for (auto kvp: cnt_of_number)
	{
		multiply *= fact(kvp.second);
	}

	ll sum = 0;
	sort(e.begin(), e.end());
	do
	{
		ll perm_sum = 0;
		for (int i = 0; i < e.size()-1; i++)
		{
			perm_sum += gcd(e[i], e[i + 1]);
			perm_sum %= mod;
		}
		perm_sum *= multiply;
		sum += perm_sum % mod;
		sum %= mod;
	} while (next_permutation(e.begin(),e.end()));
	return sum;
}

ll second_subtask(const vector<ll> elements)
{
	int n = elements.size();
	ll sol = 0;
	ll multiply = fact(n - 1) * 2;
	multiply %= mod;
	for (int i = 0; i < n; i++)
	{
		for (int j = i+1; j < n; j++)
		{
			sol += gcd(elements[i], elements[j]) * multiply;
			sol %= mod;
		}
	}
	return sol;
}

vector<ll> primes_up_to(ll n)
{
	vector<bool> is_prime(n + 1, true);
	for (int prime = 2; prime <= n; prime++)
	{
		if (is_prime[prime])
		{
			for (int j = 2 * prime; j <= n; j+=prime)
				is_prime[j] = 0;
		}
	}
	vector<ll> primes;
	for (int i = 2; i <= n; i++)
	{
		if (is_prime[i])
			primes.push_back(i);
	}
	return primes;
}

vector<vector<pair<ll, int>>> factorize_all_upto(ll n)
{
	vector<vector<pair<ll, int>>> factors(n + 1);
	for (int prime = 2; prime <= n; prime++)
	{
		if (factors[prime].empty())
		{
			for (int j = 2 * prime; j <= n; j += prime)
			{
				int temp = j;
				int prime_pow = 0;
				while (temp % prime == 0)
				{
					temp /= prime;
					prime_pow++;
				}
				factors[j].push_back({ prime,prime_pow });
			}
			factors[prime].push_back({ prime,1 });
		}
	}
	return factors;
}

vector<ll> coprimes(ll n)
{
	vector<ll> sol;
	for (int i = 1; i <= n; i++)
	{
		if (gcd(i,n) == 1)
		{
			sol.push_back(i);
		}
	}
	return sol;
}

vector<vector<ll>> comprime_upto_n(ll n)
{
	vector<vector<ll>> sol(n + 1);
	for (int i = 1; i <= n; i++)
	{
		sol[i] = coprimes(i);
	}
	return sol;
}

ll third_subtask(const vector<ll>& elements)
{
	ll max_el = *max_element(elements.begin(), elements.end());
	auto all_coprimes = comprime_upto_n(max_el);
	ll solution = 0;
	ll multiply = fact(elements.size() - 1);
	multiply %= mod;
	for (int possible_gcd = 1; possible_gcd <= max_el; possible_gcd++)
	{
		map<ll,int> quotients;
		for (int i = 0; i < elements.size(); i++)
		{
			if (elements[i] % possible_gcd == 0)
			{
				quotients[elements[i] / possible_gcd]++;
			}
		}

		ll total_count_of_gcd = 0;
		for (auto kvp: quotients)
		{
			ll quotient = kvp.first;

			ll coprime_cnt = 0;
			for (auto coprime: all_coprimes[quotient])
			{
				if (coprime == quotient)
				{
					coprime_cnt += quotients[coprime] - 1;
				}
				else
				{
					coprime_cnt += 2 * quotients[coprime];
				}
			}
			coprime_cnt *= kvp.second;
			total_count_of_gcd += coprime_cnt;
		}

		solution += ((total_count_of_gcd * multiply) % mod)*possible_gcd;
		solution %= mod;
	}

	return solution;
}

ll fourth_subtask(const vector<ll>& elements)
{
	int n = elements.size();
	ll max_el = *max_element(elements.begin(), elements.end());
	map<ll, int> element_cnt;
	for (size_t i = 0; i < n; i++)
	{
		element_cnt[elements[i]]++;
	}

	auto all_coprimes = comprime_upto_n(max_el);
	ll solution = 0;
	ll multiply = fact(elements.size() - 1);
	multiply %= mod;
	for (int possible_gcd = 1; possible_gcd <= max_el; possible_gcd++)
	{

		ll total_count_of_gcd = 0;
		for (auto kvp : element_cnt)
		{
			ll element = kvp.first;

			ll coprime_cnt = 0;
			for (auto coprime : all_coprimes[element/possible_gcd])
			{
				if (coprime == element)
				{
					coprime_cnt += element_cnt[coprime*possible_gcd] - 1;
				}
				else
				{
					coprime_cnt += 2 * element_cnt[coprime*possible_gcd];
				}
			}
			coprime_cnt *= kvp.second;
			total_count_of_gcd += coprime_cnt;
		}

		solution += ((total_count_of_gcd * multiply) % mod) * possible_gcd;
		solution %= mod;
	}

	return solution;
}

int main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);

	auto c = coprimes(100000);
	sort(c.begin(), c.end());
	for (auto i: c)
	{
		cout << i << " ";
	}

	//auto factors = factorize_all_upto(1e6);
	//auto primes = primes_up_to(1e6);

	int n; cin >> n;
	vector<ll> elements(n);
	for (size_t i = 0; i < n; i++)
		cin >> elements[i];
	
	//cout << third_subtask(elements);

	ll max_el = *max_element(elements.begin(), elements.end());
	if (n <= 1000)
	{
		cout << second_subtask(elements);
	}
	else if (max_el <= 1000)
	{
		cout << fourth_subtask(elements);
	}
	else
		cout << " ";


	return 0;
}